
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.034.
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "Module::Build" => "0.3601"
  },
  "dist_abstract" => "Collection of web-related plugins for DZil",
  "dist_author" => [
    "Nickolay Platonov <nplatonov\@cpan.org>"
  ],
  "dist_name" => "Dist-Zilla-Plugin-Web",
  "dist_version" => "0.0.7",
  "license" => "perl",
  "module_name" => "Dist::Zilla::Plugin::Web",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "Archive::Tar" => "1.52",
    "Capture::Tiny" => "0.08",
    "Data::Section" => "0.004",
    "Dist::Zilla" => "5.000000",
    "Dist::Zilla::Plugin::CheckChangesHasContent" => "0.003",
    "Dist::Zilla::Plugin::Git" => "1.112070",
    "Dist::Zilla::Plugin::GithubMeta" => "0.10",
    "Dist::Zilla::Plugin::InstallRelease" => "0.007",
    "File::Find::Rule" => "0.28",
    "File::Temp" => "0.22",
    "Getopt::LL" => "1.00",
    "IPC::Run" => "0.90",
    "JSON" => "2.90",
    "MIME::Types" => "0.00",
    "Path::Class" => "0.16",
    "String::BOM" => "0.3",
    "Text::Markdown" => "v1.0.26",
    "Text::MultiMarkdown" => "v1.0.29"
  },
  "script_files" => [],
  "share_dir" => {
    "dist" => "share"
  },
  "test_requires" => {}
);


my %fallback_build_requires = (
  "Module::Build" => "0.3601"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
