Class('Sample.Dist11', {
    
    use : [  ],
    
    
    has : {
        
        
    },
    
        
    methods : {
        
    }

})

/**

Name
====

Sample.Dist1 - Some clever yet compact description


SYNOPSIS
========

        // declaring our class
        Class('Sample.Dist1', {
        
        })
        
        // then instantiating it
        var instance = new Sample.Dist1({
        })
        
        // and doing something totally awesome with it :D
        instance.method(param1, param2)
        


DESCRIPTION
===========

`Sample.Dist1` is a stub for Joose-orientied JSAN modules.


ISA
===

None.


DOES
====

None.


TRAITS
======

None.



ATTRIBUTES
==========

### attributeName

> `AttributeType attributeName`

> Attribute description


METHODS
=======

### methodName

> `method signature`

> Method description


EXAMPLES
========

Our class can be used like this:

        // then instantiating it
        var instance = new Sample.Dist1({
        })

and like that:

        // then instantiating it
        var instance = new Sample.Dist1({
        })


GETTING HELP
============

This extension is supported via github issues tracker: <http://github.com/SamuraiJack/Module-Stub/issues>

For general Joose questions you can also visit [#joose](http://webchat.freenode.net/?randomnick=1&channels=joose&prompt=1) 
on irc.freenode.org or the forum at: <http://joose.it/forum>
 


SEE ALSO
========

Web page of this module: <http://github.com/SamuraiJack/Module-Stub/>

General documentation for Joose: <http://openjsan.org/go/?l=Joose>


BUGS
====

All complex software has bugs lurking in it, and this module is no exception.

Please report any bugs through the web interface at <http://github.com/SamuraiJack/Module-Stub/issues>



AUTHORS
=======

Nickolay Platonov <nplatonov@cpan.org>





COPYRIGHT AND LICENSE
=====================

This software is Copyright (c) 2010 by Nickolay Platonov <nplatonov@cpan.org>.

This is free software, licensed under:

  The GNU Lesser General Public License, Version 3, June 2007

*/