use strict;
use warnings;
package Dist::Zilla::Plugin::Web;
$Dist::Zilla::Plugin::Web::VERSION = '0.0.7';
# ABSTRACT: Collection of web-related plugins for DZil


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Dist::Zilla::Plugin::Web - Collection of web-related plugins for DZil

=head1 VERSION

version 0.0.7

=head1 AUTHOR

Nickolay Platonov <nplatonov@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by Nickolay Platonov.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
